rekha.plots.CDFPlot
===================

.. currentmodule:: rekha.plots

.. autoclass:: CDFPlot

   
   
   .. rubric:: Methods

   .. autosummary::
   
      ~CDFPlot.add_annotation
      ~CDFPlot.get_axes
      ~CDFPlot.save
      ~CDFPlot.save_all_formats
      ~CDFPlot.show
      ~CDFPlot.show_legend
      ~CDFPlot.update_layout
   
   

   
   
   